import { HeroSection } from "@components/HeroSection";
import { HorizontalNewsCard } from "@components/HorizontalNewsCard";
import { Breadcrumbs } from "@components/Breadcrumbs";
import { TableOfContents, Headline } from "@components/TableOfContents";
import { Pill } from "@components/Pill";
import { Prose } from "@components/Prose";
import LineSVG from "@assets/images/blog-end-line.svg";
import { INews } from "@interfaces/INews";
import { Link } from "@components/Link";
import { Edit } from "@carbon/icons-react";
import type { PropsWithChildren } from "react";
import clsx from "clsx";

interface TableOfContentsItem {
  target: string;
  headline: string;
}

export interface ArticleProps {
  titleImage?: string;
  titleImageAlt?: string;
  titleImageTag?: string;
  subtitle?: string;
  teaser?: string;
  title?: string;
  tableOfContents?: Array<TableOfContentsItem>;
  relatedContent?: Array<INews>;
  dateAndAuthor?: string;
  tags?: Array<{ target?: string; title: string }>;
  notProse?: boolean;
  preContentChildren?: React.ReactNode;
  className?: string;
  hideFooterSeparator?: boolean;
  breadcrumbs?: Array<{
    target?: string;
    title?: string;
    icon?: React.ReactElement;
  }>;
  editButtonTarget?: string;
}

export function Article({
  titleImage,
  titleImageAlt,
  children,
  subtitle,
  title,
  teaser,
  relatedContent,
  tableOfContents,
  dateAndAuthor,
  tags,
  preContentChildren,
  className,
  hideFooterSeparator,
  breadcrumbs,
  titleImageTag,
  editButtonTarget,
}: PropsWithChildren<ArticleProps>) {
  return (
    <div className={clsx("fs-w-full fs-mb-10 xl:fs-mb-0", className)}>
      {titleImage && (
        <HeroSection
          src={titleImage}
          imageTag={titleImageTag}
          alt={titleImageAlt}
        />
      )}
      <section>
        <div className="fs-grid fs-grid-cols-article fs-gap-x-4">
          <div className="fs-relative">
            {tableOfContents?.length && (
              <div className="fs-hidden xl:fs-block fs-p-10 fs-absolute fs-right-8">
                <TableOfContents>
                  {tableOfContents.map((tocItem) => (
                    <Headline key={tocItem.headline} target={tocItem.target}>
                      {tocItem.headline}
                    </Headline>
                  ))}
                </TableOfContents>
              </div>
            )}
          </div>

          <div className="fs-w-full">
            {(Boolean(breadcrumbs?.length) || editButtonTarget) && (
              <div className="fs-flex fs-justify-between fs-mt-5">
                {Boolean(breadcrumbs?.length) && (
                  <Breadcrumbs crumbs={breadcrumbs} />
                )}
                {editButtonTarget && <EditButton target={editButtonTarget} />}
              </div>
            )}
            <div className="fs-mt-10 fs-text-center">
              {subtitle && (
                <span
                  id="article-subtitle"
                  className="fs-block fs-font-karla fs-text-blue-500 fs-text-base fs-leading-6 fs-font-semibold fs-tracking-wide fs-uppercase fs-mb-4"
                >
                  {subtitle}
                </span>
              )}
              {title && (
                <h2
                  id="article-title"
                  className="fs-font-karla fs-text-grey-900 fs-text-3xl sm:fs-text-4xl xl:fs-text-6xl fs-leading-none fs-font-bold fs-tracking-tight"
                >
                  {title}
                </h2>
              )}
            </div>
            <div className="fs-mt-10 fs-mb-20 xl:fs-mb-44">
              {preContentChildren}
              <Prose>
                {teaser && <p className="lead">{teaser}</p>}
                {children}
              </Prose>
              <div className="fs-overflow-hidden">
                {!hideFooterSeparator && (
                  <img
                    className="fs-w-full fs-mt-10 fs-mb-6 fs-origin-left fs-scale-[2.5] sm:fs-scale-100"
                    src={LineSVG}
                  />
                )}
                {dateAndAuthor && (
                  <span className="fs-text-grey-900 fs-text-sm fs-leading-4 fs-font-medium">
                    {dateAndAuthor}
                  </span>
                )}
                {tags?.length && (
                  <div className="fs-flex fs-gap-2 fs-mt-2">
                    {tags.map((tag) => (
                      <Pill
                        rounded
                        key={tag.title}
                        type="dark"
                        size="sm"
                        title={tag.title}
                        href={tag.target}
                      />
                    ))}
                  </div>
                )}
              </div>
            </div>
            {relatedContent?.length && (
              <div>
                <h2 className="fs-font-karla md:fs-font-plex fs-text-black fs-text-2xl fs-leading-7 fs-font-bold md:fs-text-3xl md:fs-leading-9">
                  Related Content
                </h2>
                <div>
                  {relatedContent.map((news, index) => {
                    return (
                      index < 3 && (
                        <HorizontalNewsCard
                          key={news.id}
                          variant={news.type}
                          image={news.image}
                          title={news.title}
                          description={news.description}
                          date={news.time}
                          location={news.location}
                          category={news.category}
                          href={news.href}
                          className="fs-mt-7"
                        />
                      )
                    );
                  })}
                </div>
              </div>
            )}
          </div>
          <div className="fs-hidden xl:fs-block"></div>
        </div>
      </section>
    </div>
  );
}

interface EditButtonProps {
  target: string;
  className?: string;
}

const EditButton: React.FC<EditButtonProps> = ({
  target,
  className,
}: EditButtonProps) => {
  return (
    <div
      className={clsx(
        "fs-hidden sm:fs-block fs-font-inter fs-font-normal fs-text-sm fs-leading-5 fs-text-grey-500",
        className,
      )}
    >
      <Link
        to={target}
        className={clsx(
          "fs-flex-shrink-0 !fs-flex fs-gap-[5px] fs-items-center",
          target &&
            "hover:fs-multi-line-underline fs-multi-line-grey-500 !fs-w-auto",
        )}
      >
        <Edit />
        Edit Page
      </Link>
    </div>
  );
};
