import { INewsCategory } from "@interfaces/INews";
import { Pill } from "@components/Pill";
import { Link } from "@components/Link";
import { useMediaQuery } from "@hooks/useMediaQuery";
import clsx from "clsx";

export interface HeroBoxProps {
  title: string;
  description: string;
  selfAligned?: "left" | "right" | "center";
  categories?: INewsCategory[];
  className?: string;
  transparentOnMobile?: boolean;
  target?: string;
}

export function HeroBox({
  title,
  description,
  categories,
  className = "",
  selfAligned = "left",
  transparentOnMobile,
  target,
}: HeroBoxProps) {
  const mainStyle = transparentOnMobile ? "transparent" : "default";
  const isTabletOrDesktopSize = useMediaQuery("(min-width: 1024px)");
  const pillType = isTabletOrDesktopSize ? "dark" : "default";
  const POSITION_MAPPING: Record<string, string> = {
    left: "sm:fs-left-0 sm:fs-right-[unset] sm:fs-translate-x-[unset]",
    right: "sm:fs-right-0 sm:fs-left-[unset] sm:fs-translate-x-[unset]",
    center: "sm:fs-left-1/2 sm:fs-right-[unset] sm:-fs-translate-x-1/2",
  };
  const STYLE_MAPPING: Record<string, Record<string, string>> = {
    default: {
      outerContainer:
        "fs-group fs-w-[75%] sm:fs-w-2/3 lg:fs-w-[45%] xl:fs-w-2/5 2xl:fs-w-[32%] fs-absolute fs-z-20 fs-bottom-8 sm:fs-bottom-[unset] fs-left-1/2 fs-transform -fs-translate-x-1/2 sm:fs-p-[inherit] sm:fs-top-1/2 sm:-fs-translate-y-2/4",
      innerContainer: "fs-flex fs-flex-col fs-bg-pearl-800 fs-p-8",
      headingContainer: "",
      heading:
        "fs-font-karla fs-text-2xl sm:fs-text-3xl fs-text-white fs-multi-line-2-white sm:fs-multi-line-3-white group-hover:fs-multi-line-underline fs-leading-8 sm:fs-leading-8 fs-font-extrabold fs-tracking-tight",
      paragraph:
        "fs-mt-3 sm:fs-mt-2 fs-font-plex fs-text-lg fs-text-white fs-leading-6 sm:fs-leading-7 fs-font-normal",
      pillContainer: "fs-mt-8 sm:fs-mt-7 fs-flex fs-flex-wrap fs-gap-2",
    },
    transparent: {
      outerContainer:
        "fs-group fs-w-full sm:fs-w-2/3 lg:fs-w-[60%] xl:fs-w-2/5 2xl:fs-w-[32%] fs-absolute fs-z-20 fs-bottom-8 fs-left-0 fs-right-0 sm:fs-p-[inherit] xl:fs-top-1/2 xl:fs-bottom-[unset] xl:-fs-translate-y-1/2",
      innerContainer:
        "fs-flex fs-flex-col fs-bg-transparent lg:fs-bg-pearl-800 fs-p-4 lg:fs-p-8",
      headingContainer: "fs-order-2 lg:fs-order-1",
      heading:
        "fs-font-karla fs-text-2xl lg:fs-text-3xl fs-text-white fs-multi-line-2-white lg:fs-multi-line-3-white group-hover:fs-multi-line-underline fs-leading-8 lg:fs-leading-8 fs-font-extrabold fs-tracking-tight",
      paragraph:
        "fs-order-3 lg:fs-order-2 fs-mt-1 lg:fs-mt-2 fs-font-plex fs-text-sm lg:fs-text-lg fs-text-white fs-leading-4 lg:fs-leading-7 fs-font-normal",
      pillContainer:
        "fs-order-1 lg:fs-order-3 fs-mt-7 fs-flex fs-flex-wrap fs-gap-2 fs-mb-2 lg:fs-mb-0",
    },
  };
  return (
    <div
      className={clsx(
        STYLE_MAPPING[mainStyle]["outerContainer"],
        POSITION_MAPPING[selfAligned],
        className,
      )}
    >
      <div className={STYLE_MAPPING[mainStyle]["innerContainer"]}>
        {target ? (
          <Link to={target}>
            <div className={STYLE_MAPPING[mainStyle]["headingContainer"]}>
              <h3 className={STYLE_MAPPING[mainStyle]["heading"]}>{title}</h3>
            </div>
            <p className={STYLE_MAPPING[mainStyle]["paragraph"]}>
              {description}
            </p>
          </Link>
        ) : (
          <>
            <div className={STYLE_MAPPING[mainStyle]["headingContainer"]}>
              <h3 className={STYLE_MAPPING[mainStyle]["heading"]}>{title}</h3>
            </div>
            <p className={STYLE_MAPPING[mainStyle]["paragraph"]}>
              {description}
            </p>
          </>
        )}
        <div className={STYLE_MAPPING[mainStyle]["pillContainer"]}>
          {categories &&
            categories.map((category) => (
              <Pill
                key={category.id}
                title={category.title}
                href={category.href}
                type={transparentOnMobile ? pillType : "dark"}
                size="sm"
                rounded
              />
            ))}
        </div>
      </div>
    </div>
  );
}
